Learn R Programming

OpVaR (version 1.0.5)

fitWeights: Fitting the weights of the body and the tail for a spliced distribution

Description

Given the the weights of the spliced distribution are obtained by maximum likelihood estimation.

Usage

fitWeights(cell, thresh)

Arguments

cell

List containing the data in the component Loss

thresh

Threshold between the body and the tail.

Details

Given the threshold t, a density function \(d1\) for the body distribution and a density function \(d2\) for the tail distribution, the incidental spliced density function has the formula \(d(x)=w*d1(x)\) if \(x<=t\) and \(d(x)=(1-w)*d2(x)\) of \(x>t\). The weight w is needed to normalize the density function. It is obtained by maximum likelihood estimation. The weights depends only on the number of data points below and above the threshold, not on the distribution functions in the body and the tail.

See Also

fitThreshold, fitSpliced

Examples

Run this code
# NOT RUN {
    data(lossdat)
    thresh<-quantile(lossdat[[1]]$Loss, 0.9)
    w<-fitWeights(lossdat, thresh)
    
  
# }

Run the code above in your browser using DataLab